==> haskell-hxt-unicode-9.0.2.4-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-BcSa0ewBcaSAYs8PkEJPb7
key:                  hxt-unicode-9.0.2.4-BcSa0ewBcaSAYs8PkEJPb7
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  769bc2e1ed0596be1133f5e48a92cfee
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hxt-unicode-9.0.2.4
hs-libraries:         HShxt-unicode-9.0.2.4-BcSa0ewBcaSAYs8PkEJPb7
depends:
    base-4.15.0.0 hxt-charproperties-9.5.0.0-7S8DfdpAeUp1ftDSlDNoDk

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-unicode-9.0.2.4-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-9LykVBtuOIK6d6z5mESMS
key:                  hxt-unicode-9.0.2.4-9LykVBtuOIK6d6z5mESMS
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  e35d65cadbe1b305b16af317b9ceef78
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-9.0.2/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/hxt-unicode-9.0.2.4
hs-libraries:         HShxt-unicode-9.0.2.4-9LykVBtuOIK6d6z5mESMS
depends:
    base-4.15.1.0 hxt-charproperties-9.5.0.0-BUzcmi88CMq3OISKIjEA5L

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
